@@ -1,12 +1,13 @@
 #!/usr/bin/env python
 
+import re
 import curses
 from itertools import count
 from subprocess import Popen, PIPE
 from sys import platform, exit
 
 
-__version__ = "0.1.15"
+__version__ = "0.1.16"
 
 gunicorns = {} # gunicorn master process names/pids.
 selected_pid = None # Process ID of currently selected gunicorn master process.
@@ -25,10 +26,10 @@ background_colour = curses.COLOR_GREEN
 
 cmd_heading = "CMD"
 
-if "freebsd" in platform:
+if re.search("freebsd|openbsd", platform):
     cmd_heading = "COMMAND"
 
-if platform == "darwin" or "freebsd" in platform:
+if re.search("darwin|freebsd|openbsd", platform):
     PS_ARGS = ["ps", "-lx"]
 
     def ports_for_pids(pids):
